/// @file test.hh
/// @brief Test header file.
///
/// This header file is for testing purposes only

/// @defgroup xfc_group The Xfc Namespace
/// @namespace Xfc
/// @brief The primary namespace for the Xfce Foundation Classes.

/// @defgroup pango_group The Pango Namespace
/// @namespace Xfc::Pango
/// @ingroup xfc_group
/// @brief The C++ framework for the Pango text handling library.
///
/// Pango is a library for internationalized text handling. It centers
/// around the Pango::Layout object, representing a paragraph of text.
/// Pango provides the engine for Gtk::TextView, Gtk::Label, Gtk::Entry
/// and other widgets that display text.

namespace Xfc {

namespace Pango {

/// @enum Underline
/// Underline is used to specify whether text should be underlined, and if so,
the type of underlining.

enum Underline
{
	UNDERLINE_NONE = PANGO_UNDERLINE_NONE,
	///< No underline should be drawn.

	UNDERLINE_SINGLE = PANGO_UNDERLINE_SINGLE,
	///< A single underline should be drawn.

	UNDERLINE_DOUBLE = PANGO_UNDERLINE_DOUBLE,
	///< A double underline should be drawn.

	UNDERLINE_LOW = PANGO_UNDERLINE_LOW,
	///< A single underline should be drawn at a position beneath the ink extents
	///< of the text being underlined; this should be used only for underlining
	///< single characters, such as for keyboard accelerators; UNDERLINE_SINGLE
	///< should be used for extended portions of text.
	
	UNDERLINE_ERROR = PANGO_UNDERLINE_ERROR
	///< A wavy underline should be drawn below; this underline is typically used
	///< to indicate an error such as a possilble mispelling; in some cases an 
	///< contrasting color may automatically be used.
};

} // namespace Pango

} // namespace Xfc

 